# Ordo

Traditional Catholic Ordo and Calendar.

![code size](https://img.shields.io/github/repo-size/corei8/Ordo?style=flat-square)
![language](https://img.shields.io/github/languages/top/corei8/Ordo?style=flat-square)
![frequency](https://img.shields.io/github/commit-activity/m/corei8/Ordo?style=flat-square)

## Installation

```bash
pip install ordotools
```

## Python Specifications

Python 3.x.x 64-bit

*Dependencies (for development only):*

[dateutil](https://dateutil.readthedocs.io/en/stable/)
```bash
pip install python-dateutil
```

## Overview

The temporal cycle is generated by a class as a dictionary. The sanctoral
cycle is made up of several files for country and diocese, and each file is
a "dynamic" dictionary contained in a class, which self-adjusts depending
on the year. The sanctoral cycle is the first to be compiled, then it is
added to the temporal cycle.

The output is a complex dictionary. Each key is a datetime object, and each
item contains the name of the feast together with all the data necessary to
determine the peculiarities of the office and Mass(es) of that day.

Easter is the first feast (every "event" is treated as a feast) to be
determined, since most of the liturgical year depends upon the date of
Easter. Christmas, being static with regard to its date, requires that we
only find the day of the week on which it falls. We begin building the
temporal calendar with January 1st.

## Progress

- [x] Temporal Calendar
- [x] Combined Temporal and Sanctoral Calendar
- [x] Method for adding other countries and dioceses
- [x] Colors of Mass and Office
- [x] Fasting rules
- [ ] Commemorations
- [ ] Masses
- [ ] Votives, Requiems, etc.
- [ ] Phases of the Moon
- [ ] Martyrology letter
- [ ] Vespers
- [ ] Lessons for Laudes
- [ ] Our Lady's Saturday
- [ ] Prime
- [ ] Little Hours
- [ ] Alternative Masses
- [ ] Solemnities
                        
